class DashboardComponentsController < ApplicationController
  model_data_store(DashboardComponent)
  before_action :set_target, only: [:show, :update, :destroy, :run]

  def create
    @model = model_type.new(model_params)
    if @model.save
      render json: @model, status: :created, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
    @model.get_data!
  end

  def update
    if @model.update(model_params)
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
    @model.get_data!
  end


  def run
    @model.get_data!
    render json: @model, status: :accepted
  end

  private

  # Only allow a list of trusted parameters through.
  def model_params
    provided_params = params.require(:dashboard_component).permit(:name, :desc, :parameters, :refresh_interval, :data, :display_type, :display_options, :dashboard_target_id, :run_user_id)
    if provided_params[:run_user_id] && (provided_params[:run_user_id] != '')
      token = provided_params[:run_token] = RxModule::Authorization.generate_proxy_routine_token(:dashboard_proxy, provided_params[:run_user_id])
      if token && (token != '')
        provided_params.permit(:run_token)
        provided_params[:run_token] = token
      end
    end
    provided_params
  end
end
