import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {i18n, rxuScope, UserPicker} from "@rx-suite/ui";
import {DashboardTargetModel} from "../../../stores/DashboardTargetStore";
import {t, Trans} from "@lingui/macro";
import {Typography} from "@material-ui/core";

export type DashboardComponentRunAsProps = {
    component: DashboardComponentModel
}

export const DashboardComponentRunAs: React.FunctionComponent<DashboardComponentRunAsProps> = observer(({component}) => {
    const target = component.viewModel.dashboard_target as DashboardTargetModel;
    if (!target || target.module_id !== 'rx_plore') {
        return null;
    }

    return (
        <UserPicker
            name={'run_user_id'}
            onChange={component.handleSelectChange}
            value={Number(component.viewModel.run_user_id) || ''}
            scope={rxuScope}
            label={i18n._(t`Run Component As`)}
            clearable
            hideIfNoScopeResults
            hint={{
                title: i18n._(t`Run As Another User`),
                children: <>
                    <Typography variant={'body1'}>
                        <Trans>Communicate with the Rx-Universe API using the credentials of the selected user. Only
                            users who have authenticated with Rx-Universe will be displayed.
                        </Trans>
                    </Typography>
                    <Typography variant={'body1'}>
                        <a href={"/api/rx_module/profile"}><Trans>You can authenticate with Rx-Universe on your profile
                            page</Trans></a>
                    </Typography>
                </>
            }}
        />
    );
});
