import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {i18n, SelectField, useReadonlyContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type TitleOptionsFieldProps = {
    component: DashboardComponentModel
}

export const TitleOptionsField: React.FunctionComponent<TitleOptionsFieldProps> = observer(({component}) => {
    const readOnly = useReadonlyContext();
    React.useEffect(() => {
        if (((component.viewModel.display_options || {}).title || {}).position === undefined) {
            component.nestedAssignment(`display_options.title.position`, 'top-left');
        }
    }, [component])
    const label = i18n._(t`Display Title`);
    return <SelectField label={label}
                        name={`display_options.title.position`}
                        options={[
                            {label: i18n._(t`Left`), value: 'top-left'},
                            {label: i18n._(t`Middle`), value: 'top-middle'},
                            {label: i18n._(t`Right`), value: 'top-right'},
                            {label: i18n._(t`None`), value: 'omit'},
                        ]}
                        value={((component.viewModel.display_options || {}).title || {}).position || ''}
                        disabled={readOnly}
                        onChange={component.handleSelectChange}
                        hint={{
                            title: label,
                            text: i18n._(t`Choose where to put the component name, or omit it entirely`)
                        }}
    />

});