import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {Gauge} from '@rx-suite/ui'

export type DashboardComponentGaugeProps = {
    component: DashboardComponentModel
};

export const DashboardComponentGauge: React.FunctionComponent<DashboardComponentGaugeProps> = observer(({component}) => {
    const data = (component.viewModel.data || {}).metrics || {};
    const targets = component.targetIds;
    const goals = (component.viewModel.display_options || {}).goals || {} as { [s: string]: string | number };
    const maxGoal = Math.max(...(Object.values(goals) as [string | number]).map((g => parseInt(g.toString(), 10))), 1);
    const effectiveGoals = targets.map((target: string) => {
        let goal = parseInt((goals[target] || 100).toString(), 10);
        if (goal === 0) {
            goal = maxGoal;
        }
        return goal;
    })
    const parsedSeries = targets.map((target, i) => {
        return (data[target] / effectiveGoals[i]) * 100;
    });

    let title = '';
    const options = { } as any;

    if ((((component.viewModel.display_options || {}).title || {}).position === 'top-left') || (((component.viewModel.display_options || {}).title || {}).position === undefined)) {
        title = component.viewModel.name;
        options.title = {};
        options.title.align = 'left';
        options.title.text = title;
    } else if (((component.viewModel.display_options || {}).title || {}).position === 'top-middle') {
        title = component.viewModel.name;
        options.title = {};
        options.title.align = 'center';
        options.title.text = title;
    } else if (((component.viewModel.display_options || {}).title || {}).position === 'top-right') {
        title = component.viewModel.name;
        options.title = {};
        options.title.align = 'right';
        options.title.text = title;
    }

    if (component.isNew) {
        const fakeSeries = [55];
        return <Gauge series={fakeSeries}
                      title={title}
                      labels={['A']}
                      options={{
                          ...options,
                          plotOptions: {
                              radialBar: {
                                  dataLabels: {
                                      total: {
                                          show: true,
                                          label: component.name,
                                          fontSize: '20px',
                                          // formatter: () => (targets.length === 1) ? `${data[targets[0]]}/${effectiveGoals[0]}` : ''
                                      }
                                  }
                              }
                          },
                          legend: {
                              show: fakeSeries.length !== 1,
                          },
                          colors: ['#DCDCDC']
                      }}
        />;
    } else {
        return <Gauge series={parsedSeries}
                      title={title}
                      labels={targets.map((target, i) => `${component.targetParameterName(target)}: ${data[target]}/${effectiveGoals[i]}`)}
                      options={{
                          ...options,
                          plotOptions: {
                              radialBar: {
                                  dataLabels: {
                                      total: {
                                          show: true,
                                          label: component.name,
                                          fontSize: '20px',
                                          formatter: () => (targets.length === 1) ? `${data[targets[0]]}/${effectiveGoals[0]}` : ''
                                      }
                                  }
                              }
                          },
                          legend: {
                              show: targets.length !== 1,
                          }
                      }}
        />;
    }
});
