import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {makeStyles} from "@material-ui/core/styles";
import {i18n, PieChart} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export type DashboardComponentPieChartProps = {
    component: DashboardComponentModel
};

const useStyles = makeStyles(theme => ({
    artificialMultiWrapper: {
        display: 'flex',
        flexDirection: 'row',
        width: '100%',
        height: '100%',
    }
}));

export const DashboardComponentPieChart: React.FunctionComponent<DashboardComponentPieChartProps> = observer(({component}) => {
    const classes = useStyles();
    const data = component.viewModel.data || {};
    const series = data.series || [{}];
    const labels = (data.categories || []).map((c: { name: string }) => c.name);

    if (component.isNew) {
        const fakeSeries = [Math.floor(Math.random() * 10), Math.floor(Math.random() * 10), Math.floor(Math.random() * 10)]
        return <div className={classes.artificialMultiWrapper}><PieChart series={fakeSeries}
                                                                         key={JSON.stringify(fakeSeries)}
                                                                         options={{
                                                                             ...component.graphOptions,
                                                                             labels: ['A', 'B', 'C'],
                                                                             colors: ['#DCDCDC', "#C0C0C0", "#808080"]
                                                                         }}/></div>
    } else {
        return <div className={classes.artificialMultiWrapper}>
            {series.map((s: any) => {
                    const series = (s || {}).data || [];
                    if (series.every((d: number) => d === 0)) {
                        series.push(1);
                        labels.push(i18n._(t`No Data`));
                    }
                    return <PieChart series={series}
                                     key={JSON.stringify(s || {})}
                                     options={{...component.graphOptions, labels: labels}}/>
                }
            )}
        </div>
    }
});
