import * as React from 'react';
import {observer} from "mobx-react-lite";
import {i18n, InputField, PaddedPaper, useReadonlyContext} from "@rx-suite/ui";
import {DashboardGroupDashboardModel} from "../../stores/DashboardGroupDashboardStore";
import {t} from "@lingui/macro";
import {Grid, IconButton, Typography} from "@material-ui/core";
import {Delete, DragIndicator} from "@material-ui/icons";
import {DashboardModel} from "../../stores/DashboardStore";
import {makeStyles} from "@material-ui/core/styles";
import {DashboardGroupModel} from "../../stores/DashboardGroupStore";
import {HintButton} from "@rx-suite/ui/build";

const useStyles = makeStyles(theme => ({
    danger: {
        color: theme.palette.error.main
    },
    interval: {
        display: 'flex'
    }
}));

export const DashboardGroupDashboardItem: React.FunctionComponent<{ member: DashboardGroupDashboardModel }> = observer(({member}) => {
    const readOnly = useReadonlyContext();
    const classes = useStyles();
    const handleRemove = React.useCallback(() => {
        if (member.dashboard_group) {
            (member.dashboard_group as DashboardGroupModel).removeMember(member);
        }
    }, [member]);
    const displayLabel = i18n._(t`Display (Seconds)`);
    return (
        <PaddedPaper>
            <Grid container spacing={2} alignItems={'flex-end'}>
                <Grid item xs={1}>
                    <DragIndicator/>
                </Grid>
                <Grid item xs={6}>
                    <Typography
                        variant={"h6"}>{((member.viewModel.dashboard as DashboardModel) || {}).name || ''}</Typography>
                </Grid>
                <Grid item xs={4} className={classes.interval}>
                    <InputField label={displayLabel}
                                value={member.viewModel.interval}
                                type={'number'}
                                name={'interval'}
                                disabled={readOnly}
                                onChange={member.handleChange}/>
                    <HintButton
                        title={displayLabel}>{i18n._(t`The dashboard on display will advance after this many seconds`)}</HintButton>
                </Grid>
                <Grid item xs={1}>
                    <IconButton className={classes.danger} onClick={handleRemove}>
                        <Delete/>
                    </IconButton>
                </Grid>
            </Grid>
        </PaddedPaper>
    )
});
