import * as React from 'react';
import {observer, Observer} from "mobx-react-lite";
import {DashboardGroupModel} from "../../stores/DashboardGroupStore";
import {DragDropContext, Draggable, Droppable, DropResult} from 'react-beautiful-dnd';
import {useReadonlyContext} from "@rx-suite/ui";
import {makeStyles} from "@material-ui/core/styles";
import classNames from 'classnames';
import {DashboardGroupDashboardModel} from "../../stores/DashboardGroupDashboardStore";
import {DashboardGroupDashboardItem} from "./DashboardGroupDashboardItem";
import {runInAction} from "mobx";
import {t} from "@lingui/macro";
import {Typography} from "@material-ui/core";
import {HintButton, i18n} from "@rx-suite/ui/build";

const useStyles = makeStyles(theme => ({
    list: {
        display: 'inline-flex',
        flexDirection: 'column',
        height: '100%',
        width: '100%'
    },
    listDragOver: {
        background: theme.palette.success.light
    },
    item: {
        width: '100%',
        marginBottom: theme.spacing(1)
    },
    itemDrag: {
        background: theme.palette.info.light
    },
    title: {
        display:'flex'
    },
}));

export const DashboardGroupDashboardList: React.FunctionComponent<{ group: DashboardGroupModel }> = observer(({group}) => {
    const readOnly = useReadonlyContext();
    const classes = useStyles();
    const onDragEnd = (result: DropResult) => {
        runInAction(() => {
            if (!result.destination) {
                return;
            }
            let counter = 0;
            const destinationIndex = result.destination.index;
            group.viewModel.members.forEach((member, i) => {
                if (i === destinationIndex) {
                    counter++;
                }
                if (member.getId().toString() === result.draggableId.toString()) {
                    member.nestedAssignment('rank', destinationIndex);
                } else {
                    member.nestedAssignment('rank', counter);
                }
                counter++;
            });
            group.normalizeRanks();
        });
    };
    const label = i18n._(t`Dashboard Sequence`);
    return <>
        <div className={classes.title}><Typography variant={"h5"}>{label}</Typography><HintButton title={label}>{i18n._(t`Drag and drop the dashboards to change the order in which the dashboard slideshow rotates`)}</HintButton></div>
        <DragDropContext onDragEnd={onDragEnd}>
            <Droppable droppableId={"d-g-d"} direction={"vertical"}
                       isDropDisabled={readOnly}>
                {(provided, snapshot) => (
                    <Observer>
                        {() => (
                            <div ref={provided.innerRef} {...provided.droppableProps}
                                 className={classNames(
                                     classes.list,
                                     snapshot.isDraggingOver && classes.listDragOver
                                 )}>
                                {group.members.map((member: DashboardGroupDashboardModel) => (
                                    <Draggable
                                        isDragDisabled={readOnly}
                                        key={member.getId()}
                                        draggableId={member.getId().toString()}
                                        index={member.viewModel.rank}>
                                        {(provided, snapshot) => (
                                            <Observer>
                                                {() => (
                                                    <div
                                                        ref={provided.innerRef}
                                                        {...provided.draggableProps}
                                                        {...provided.dragHandleProps}
                                                        className={classNames(
                                                            classes.item,
                                                            snapshot.isDragging && classes.itemDrag
                                                        )}
                                                        style={provided.draggableProps.style}>
                                                        <DashboardGroupDashboardItem member={member}/>
                                                    </div>
                                                )}
                                            </Observer>
                                        )}
                                    </Draggable>
                                ))}
                                {provided.placeholder}
                            </div>
                        )}
                    </Observer>
                )}
            </Droppable>
        </DragDropContext>
    </>
});
