import {Dialog, DialogContent, DialogTitle} from "@material-ui/core";
import {t} from "@lingui/macro";
import {DashboardComponentsForm} from "../../pages/dashboard_components/DashboardComponentsForm";
import {DashboardComponentStore} from "../../stores/DashboardComponentStore";
import * as React from "react";
import {DashboardModel} from "../../stores/DashboardStore";
import {observer} from "mobx-react-lite";
import {i18n} from "@rx-suite/ui/build";
import {when} from "mobx";

export type NestedComponentFormProps = {
    dashboard: DashboardModel,
    open: boolean,
    setOpen: ((newOpen: boolean) => void)
};


export const NestedComponentForm: React.FunctionComponent<NestedComponentFormProps> = observer(({dashboard, open, setOpen}) => {
    const closeForm = React.useCallback(() => setOpen(false), [setOpen]);
    const afterSubmit = React.useCallback((e, resp) => {
        console.dir(resp);
        when(() => !!DashboardComponentStore.get(resp.id), () => {
            dashboard.addComponent(DashboardComponentStore.get(resp.id)!);
        })
        closeForm();
    }, [dashboard, closeForm])
    return <Dialog open={open} onClose={closeForm} maxWidth={false}>
        <DialogTitle>{i18n._(t`New Component`)}</DialogTitle>
        <DialogContent>
            {/*//make a new model for each opening*/}
            {open && <DashboardComponentsForm model={DashboardComponentStore.createModel()} afterSubmit={afterSubmit}
                                              suppressRedirect/>}
        </DialogContent>
    </Dialog>
});