import * as React from 'react';
import {FormEvent, useState} from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, FormProps, i18n, ModelForm, ModelInput, PaddedPaper} from "@rx-suite/ui";
import {DashboardGrid} from "../../components/dashboards/DashboardGrid";
import {DashboardModel} from "../../stores/DashboardStore";
import {ExpansionPanel, ExpansionPanelSummary, Typography} from "@material-ui/core";
import {Add, ExpandMore} from "@material-ui/icons";
import {t} from "@lingui/macro";
import {AddComponentTable} from "../../components/dashboards/AddComponentTable";
import {makeStyles} from "@material-ui/core/styles";
import {NestedComponentForm} from "../../components/dashboards/NestedComponentForm";
import {FullscreenButton} from "@rx-suite/ui/build";

const useStyles = makeStyles(theme => ({
    fullscreenLayout: {
        height: 560,
        "&:fullscreen": {
            height: '100vw',
            width: '100vh',
            overflow: 'auto',
            backgroundColor: '#fafafa',
            padding: theme.spacing(2),
        }
    },
    layoutTitle: {
        display: 'inline-block'
    },
    gridWrapper: {
        height: '90%'
    }
}));

export type DashboardFormProps = {
    afterSubmit?: (event: FormEvent, resp: any) => void,
    suppressRedirect?: boolean
} & FormProps

export const DashboardForm: React.FunctionComponent<DashboardFormProps> = observer(({model, readOnly, suppressRedirect, afterSubmit}) => {
    const classes = useStyles();
    const [formOpen, setFormOpen] = useState(false);
    const openForm = React.useCallback(() => setFormOpen(true), [setFormOpen]);
    const fullscreenLayoutRef = React.createRef<HTMLDivElement>();

    return (
        <PaddedPaper>
            <NestedComponentForm dashboard={model as DashboardModel} open={formOpen} setOpen={setFormOpen}/>
            <ModelForm model={model} readOnly={readOnly} suppressWrapper suppressImportExport
                       suppressRedirect={suppressRedirect}
                       afterSubmit={afterSubmit}>
                <ModelInput name={"name"}/>
                <ModelInput name={"desc"} multiline rowsMax={4}/>
                {!readOnly && <>
                    <ExpansionPanel>
                        <ExpansionPanelSummary expandIcon={<ExpandMore/>}>
                            <Typography variant={"h5"}>{i18n._(t`Add Existing Component`)}</Typography>
                        </ExpansionPanelSummary>
                        <AddComponentTable dashboard={model as DashboardModel} openForm={openForm}/>
                    </ExpansionPanel>
                    <ButtonField
                        text={i18n._(t`Make New Component`)}
                        startIcon={<Add/>}
                        onClick={openForm}
                    />
                </>}
                <div className={classes.fullscreenLayout} ref={fullscreenLayoutRef}>
                    <div>
                        <Typography variant={"h6"} className={classes.layoutTitle}>{i18n._(t`Layout`)}</Typography>
                        <FullscreenButton fullscreenRef={fullscreenLayoutRef}/>
                    </div>
                    <div className={classes.gridWrapper}>
                        <DashboardGrid dashboard={model as DashboardModel} editMode={!readOnly}/>
                    </div>
                </div>
            </ModelForm>
        </PaddedPaper>
    )
});
