import {attribute, DataStore, model, Model, Transport} from '@rx-suite/data';
import {i18n} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import * as yup from 'yup';
import {action} from "mobx";
import {Layout} from "react-grid-layout";

@model({
    transportLayer: new Transport("/api/dashboard_component_placements", "dashboard_component_placement"),
    permissionTarget: "DashboardComponent",
    routingInfo: {}
})
export class DashboardComponentPlacementModel extends Model {
    @attribute({
        label: i18n._(t`X`),
        validation: yup.number()
    })
    x: number = 0;

    @attribute({
        label: i18n._(t`Y`),
        validation: yup.number()
    })
    y: number = 0;

    @attribute({
        label: i18n._(t`Height`),
        validation: yup.number()
    })
    height: number = 1;

    @attribute({
        label: i18n._(t`Width`),
        validation: yup.number()
    })
    width: number = 1;

    @attribute({
        label: i18n._(t`Component`),
        connects: 'DashboardComponentModel',
        validation: yup.number(),
        autoTable: false
    })
    dashboard_component_id: number | undefined = undefined;

    @attribute({
        label: i18n._(t`Dashboard`),
        connects: 'DashboardModel',
        validation: yup.number(),
        autoTable: false
    })
    dashboard_id: number | undefined = undefined;

    @action.bound
    handleLayoutChange(newLayout: Layout) {
        this.nestedAssignment('x', newLayout.x)
        this.nestedAssignment('y', newLayout.y)
        this.nestedAssignment('width', newLayout.w)
        this.nestedAssignment('height', newLayout.h)
    }
}

export const DashboardComponentPlacementStore = DashboardComponentPlacementModel.store as DataStore<DashboardComponentPlacementModel>;
DashboardComponentPlacementStore.setLimit(10000);
