import {attribute, DataStore, model, Model, Types} from '@rx-suite/data';
import {i18n} from "@rx-suite/ui/build";
import {t} from "@lingui/macro";
import * as yup from 'yup';
import {computed} from "mobx";
import {Parameter} from "./Types";
import {DashboardGroupStore} from "./DashboardGroupStore";

@model({
    transportLayer: "/api/dashboard_targets",
    routingInfo: {}
})
export class DashboardTargetModel extends Model {
    types: Types = {
        ui_hints: 'json',
        parameters: 'json',
        returns: 'json',
    };
    @attribute({
        validation: yup.string()
    })
    module_id: string = '';

    @attribute({
        label: i18n._(t`Module`),
        validation: yup.string()
    })
    module_name: string = '';

    @attribute({
        label: i18n._(t`ID`),
        validation: yup.string()
    })
    dashboard_id: string = '';

    @attribute({
        label: i18n._(t`Name`),
        validation: yup.string()
    })
    name: string = '';

    @attribute({
        label: i18n._(t`Description`),
        validation: yup.string()
    })
    desc: string = '';

    @attribute({
        validation: yup.mixed()
    })
    ui_hints: any = {};

    @attribute({
        validation: yup.mixed()
    })
    parameters: { [s: string]: Parameter } = {};

    @attribute({
        validation: yup.mixed()
    })
    returns: any = null;

    @attribute({label: i18n._(t`Created At`), autoForm: false})
    created_at: Date = new Date();

    @attribute({label: i18n._(t`Updated At`), autoForm: false})
    updated_at: Date = new Date();

    @computed
    get displayTypes() {
        if (this.ui_hints && this.ui_hints.type) {
            switch (this.ui_hints.type) {
                case 'category_chart':
                    return [
                        {label: i18n._(t`Bar`), value: 'bar'},
                        {label: i18n._(t`Pie`), value: 'pie'},
                        {label: i18n._(t`Radar`), value: 'radar'},
                        {label: i18n._(t`Polar Area`), value: 'polararea'},
                        {label: i18n._(t`Counter`), value: 'counter'}
                    ];
                case 'dual_axis_chart':
                    return [
                        {label: i18n._(t`Bar`), value: 'bar'},
                        {label: i18n._(t`Line`), value: 'line'},
                        {label: i18n._(t`Scatter`), value: 'scatter'},
                        {label: i18n._(t`Heat Map`), value: 'heatmap'},
                    ];
                case 'table':
                    return [{label: i18n._(t`Table`), value: 'table'}];
                case 'gauge':
                    return [
                        {label: i18n._(t`Gauge`), value: 'gauge'},
                        {label: i18n._(t`Counter`), value: 'counter'}
                    ];
                default:
                    return [];
            }
        }
        return [];
    }

}

export const DashboardTargetStore = DashboardTargetModel.store as DataStore<DashboardTargetModel>;
DashboardTargetStore.setLimit(10000);