class DashboardRoutine < RxModule::Routine
  class << self
    # component_id => rufus_id
    def dashboard_jobs
      @_jobs ||= {}
    end

    def set_next_run(component)
      begin
        job = get_job!(component)
        if job.next_time && (job.next_time > (component.updated_at + component.refresh_interval + 40))
          job.next_time = component.updated_at + component.refresh_interval
        end
      rescue StandardError => err
        component.update(last_run_error: "Schedule failure (#{err.message})")
        Rails.logger.error { {msg: 'Dashboard component failed to schedule', component: component&.as_json} }
      end
    end

    def get_job!(component)
      job = get_job(component.id)
      unless job
        job_id = Rufus::Scheduler.s.at(component.updated_at + component.refresh_interval) do
          ActiveRecord::Base.connection_pool.with_connection do
            component.reload
            component.get_data!
          end
        end
        dashboard_jobs[component.id] = job_id
        job = Rufus::Scheduler.s.job(job_id)
      end
      job
    end

    def get_job(id)
      Rufus::Scheduler.s.job(dashboard_jobs[id])
    end

    def clear_job(id)
      if (job = get_job(id))
        begin
          dashboard_jobs.delete(id)
          job.unschedule
          job.kill
        rescue StandardError => e
          # The scheduler purposely raises an exception to kill
        end
      end
    end

    def clear_deleted_jobs(components_to_keep)
      ids_to_keep = components_to_keep.map { |c| c[:id] }
      dashboard_jobs.keep_if do |component_id, _rufus_id|
        if ids_to_keep.include?(component_id)
          true
        else
          clear_job(component_id)
          false
        end
      end
    end

    def frequency
      "15s"
    end

    def work
      components = DashboardComponent.all
      clear_deleted_jobs(components)
      components.each do |c|
        set_next_run(c)
      end
    end
  end
end